-----------------------------------------------------------
-----------------------------------------------------------
function Init()
	Card.SetName("Nuclear Plant")

	Card.SetType("Building")
	Card.SetImage("Card_Building_Generator")
	Card.SetDescription("Nuclear plants produce abundant power but require a constant source of radioactive fuel and the waste is difficult to deal with. We should make sure this plant is always in good condition or it may become dangerous.")
	Card.SetAmbientSound("EventPowerPlant")
	Card.AddDestructionSound("Demolition")
	
	Card.SetHealth(5)
	
	Card.SetLabourCost(16)
	Card.SetMaterialCost(6)
	Card.SetPolymerCost(4)

	Card.SetMaterialUpkeep(1)
	Card.SetWaterUpkeep(1)
	
	Card.ProducePower(10)
	Card.ProducePollution(1)
end

-----------------------------------------------------------
-----------------------------------------------------------
function EntersPlay()
end

-----------------------------------------------------------
-----------------------------------------------------------
function LeavesPlay()
	--Plant won't melt down if it's turned off
	local enabled = Card.GetIsFunctional()
	if enabled == false then
		return
	end
	
	--If removed by damage, explodes
	local health = Card.GetHealth()
	local damage = Card.GetConditionCount("All")

	if damage >= health then
		Game.ShowMessage("Meltdown!", "Our nuclear plant has become too unstable and has exploded. We managed to prevent a full meltdown but the damage it has caused is severe.")

		Game.DamageRandomBuildings(3)
		Game.DamageRandomBuildings(2)
		Game.DamageRandomBuildings(1)

		Game.DamageRandomColonists(3, "Damage")
		Game.DamageRandomColonists(2, "Damage")
		Game.DamageRandomColonists(1, "Damage")
	end
end

-----------------------------------------------------------
-----------------------------------------------------------
function Complete()
end

-----------------------------------------------------------
-----------------------------------------------------------
function StartTurn()
end

-----------------------------------------------------------
-----------------------------------------------------------
function EndTurn()
	--Plant won't melt down if it's turned off
	local enabled = Card.GetIsFunctional()
	if enabled == false then
		return
	end
	
	--If no one is maintaining the power plant and it is damaged then it can melt down
	local engineering = Work.GetAssignedSkillCount("Engineering")
	if engineering > 0 then
		return
	end

	local damage = Card.GetConditionCount("All")
	local rand = Game.GetRandomNumber(0, 10)
	if rand < damage then
		local health = Card.GetHealth()

		if (damage + 2) < health then
			Game.ShowMessage("Alert!", "The damage to our nuclear plant has made it unstable, we should repair it before it gets worse!")
		end
		
		Card.AddCondition("Damage")
		Card.AddCondition("Damage")
	end
end
