-----------------------------------------------------------
-----------------------------------------------------------
function Init()
	Card.SetName("Pulsing Signal")
	
	Card.SetType("Expedition")
	Card.SetImage("Card_Exp_WeakSignal")
	Card.SetDescription("This pulsing signal is being broadcast from a ravine to the South.\n\nIt's definitely artificial but doesn't resemble anything our equipment would send.\n\nWe should put together a team to investigate.")
	Card.AddRecommendedSkills({"Engineering"});
	Card.SetAmbientSound("EventSignal")
	
	Card.SetLabourCost(16)
end

-----------------------------------------------------------
-----------------------------------------------------------
function EntersPlay()
end

-----------------------------------------------------------
-----------------------------------------------------------
function LeavesPlay()
end

-----------------------------------------------------------
-----------------------------------------------------------
function Complete()
	Game.ShowMessage("Expedition Complete", "Our expedition to the ravine discovered the signal was coming from some ancient alien structures, fallen to ruin long ago.\n\nOur scientists are excited by the find and believe we may be able to improve our own technology by studying these ruins.")
	
	Game.SpawnCard("AlienTechnology")
	Game.DelayActions(0.5)

	local desc = "Amongst the ruins, we encountered a humanoid robot. It's definitely alien in design and is standing motionless. What should we do?"
	local choice0 = "Attempt to activate it"
	local choice1 = "Leave it alone"
	local choice2 = "Destroy it"

	Game.ShowChoice(desc, choice0, choice1, choice2, "ChoiceComplete")
end

-----------------------------------------------------------
-----------------------------------------------------------
function StartTurn()
end

-----------------------------------------------------------
-----------------------------------------------------------
function EndTurn()
end

-----------------------------------------------------------
-----------------------------------------------------------
function ChoiceComplete(choiceIndex)
	if choiceIndex == 0 then
		--Activate it
		local engineering = Work.GetAverageWorkBySkill("Engineering")

		if engineering > 1.5 then
			--Guaranteed good result
			Game.ShowMessage("It's Alive!", "Our engineers have reactivated the robot. This incredible machine appears to be semi-sentient, although it doesn't speak, it can follow instructions and is quite skilled in engineering.\n\nIt doesn't need to eat or drink, however we have detected it creating a minor drain on our power grid.")

			Game.SpawnCard("FriendlyAutomaton")
			
		else
			--Random result
			local rand = Game.GetRandomNumber(0, 3)

			if rand == 0 then
				--Friendly
				Game.ShowMessage("It's Alive!", "Our colonists have reactivated the robot. This incredible machine appears to be semi-sentient, although it doesn't speak, it can follow instructions and is quite skilled in engineering.\n\nIt doesn't need to eat or drink, however we have detected it creating a minor drain on our power grid.")

				Game.SpawnCard("FriendlyAutomaton")

			elseif rand == 1 then
				--Friendly but turns hostile
				Game.ShowMessage("It's Alive!", "Our colonists have reactivated the robot. This incredible machine appears to be semi-sentient, although it doesn't speak, it can follow instructions and is quite skilled in engineering.\n\nIt doesn't need to eat or drink, however we have detected it creating a minor drain on our power grid.")

				Game.SpawnCard("UnstableAutomaton")

			else
				--Hostile
				Game.ShowMessage("Alert!", "We reactivated the robot but it immediately attacked and one of our colonists was injured!\n\nNow it's attacking the colony, we must destroy it!")

				local nWorkerID = Work.GetRandomWorkerInstanceID()
				Game.AddCardCondition(nWorkerID, "Damage")
				
				Game.SpawnCard("HostileAutomaton")
			end
		end

	elseif choiceIndex == 1 then
		--Leave it
		Game.ShowMessage("Caution is a Virtue", "Deciding not to trust the alien machine, our colonists avoided it.\n\nIt remains standing in the middle of the ravine, dormant.")

	elseif choiceIndex == 2 then
		--Destroy it
		Game.ShowMessage("Reduced to Scrap", "Deciding not to trust the alien machine, our colonists reduced it to scrap and managed to salvage some spare materials.\n\n<align=\"center\">Gained: <sprite name=\"Materials\">+3 <sprite name=\"Polymers\">+3</align>")
		
		Stockpile.AddMaterials(3)
		Stockpile.AddPolymers(3)
	end
end